@@ -1,7 +1,7 @@
-use mini_lang::{StdPrinter, EagerEval, LazyEval, execute, MiniError, MiniResult};
-use structopt::StructOpt;
+use mini_lang::{execute, EagerEval, LazyEval, MiniError, MiniResult, StdPrinter};
 use std::fs::File;
 use std::io::{stdin, Read};
+use structopt::StructOpt;
 
 #[derive(Debug, StructOpt)]
 #[structopt(author, about)]
@@ -24,8 +24,13 @@ fn inner_main() -> MiniResult<()> {
     let opt = Opt::from_args();
     let mut buf = String::new();
     match opt.path {
-        Some(path) => File::open(path).map_err(MiniError::from_error)?.read_to_string(&mut buf).map_err(MiniError::from_error)?,
-        None => stdin().read_to_string(&mut buf).map_err(MiniError::from_error)?,
+        Some(path) => File::open(path)
+            .map_err(MiniError::from_error)?
+            .read_to_string(&mut buf)
+            .map_err(MiniError::from_error)?,
+        None => stdin()
+            .read_to_string(&mut buf)
+            .map_err(MiniError::from_error)?,
     };
 
     if opt.lazy {
